@@ -44,7 +44,8 @@ int main(int argc, char **argv)
     auto *job = new KDAV::DavCollectionsFetchJob(davUrl);
     job->exec();
 
-    foreach(const auto collection, job->collections()) {
+    const auto collections = job->collections();
+    for (const auto &collection : collections) {
         qDebug() << collection.displayName() << "PRIVS: " << collection.privileges();
         auto collectionUrl = collection.url();
         std::shared_ptr<KDAV::EtagCache> cache(new KDAV::EtagCache());
@@ -57,7 +58,8 @@ int main(int argc, char **argv)
             qDebug() << "items:" << itemListJob->items().size();
             qDebug() << "changed Items:" << itemListJob->changedItems().size();
             qDebug() << "deleted Items:" << itemListJob->deletedItems();
-            foreach(const auto item, itemListJob->changedItems()) {
+            const auto changedItems = itemListJob->changedItems();
+            for (const auto &item : changedItems) {
                 qDebug() << item.url().url() << item.contentType() << item.data();
                 auto itemFetchJob = new KDAV::DavItemFetchJob(item);
                 itemFetchJob->exec();
